@@ -1,5 +1,5 @@
-__version_info__ = ('0', '1', '7', '4')
-__date__ = '4 Apr 2022'
+__version_info__ = ('0', '1', '7', '5')
+__date__ = '31 Oct 2022'
 
 __version__ = '.'.join(__version_info__)
 __author__ = 'Tom Kwok'
